@@ -1,7 +1,7 @@
 "interpp.new"<-function(x, y, z, xo, yo, extrap = FALSE,
                     duplicate = "error", dupfun = NULL)
 {
-    warning("interp.new() is deprecated, use interp()")
+    warning("interpp.new() is deprecated, use interpp()")
     interpp(x, y, z,
             xo,
             yo, linear=FALSE,
